<?php

/*
Copyright (C) 2009-2013, Rémi Jean (zwiicms@outlook.com)
<http://zwiicms.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General License for more details.

You should have received a copy of the GNU General License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

class files_manager extends zwii
{
	var $icons_path,
		$file_path;

	/*
		Système
	*/

	function __construct()
	{
		parent::__construct();
		$this->icons_path = 'zwii/plugins/files_manager/extras/icons/';
		$this->file_path = empty($this->plugins['files_manager']['files_path']) ? './' : $this->plugins['files_manager']['files_path'];
		if(!is_dir($this->file_path))
		{
			mkdir($this->file_path);
		}
	}

	function builder()
	{
		$in = !empty($this->url[1]) ? $this->url[1] : 'home';
		switch($in)
		{
			case 'home' :
				$this->title = $this->t('Gestionnaire de fichiers');
				return $this->home();
				break;

			case 'rename' :
				$this->title = $this->t('Renommer un fichier');
				return $this->rename();
				break;

			case 'delete' :
				return $this->delete();
				break;

			default :
				return $this->error;
		}
	}

	/*
		Plugins
	*/

	function home()
	{
		if(isset($_POST['submit']))
		{
			$this->upload();
			return $this->redirect('/files_manager');
		}
		else
		{
			return '<h2>' . $this->title . '</h2>'
				. '<form name="form" method="post" enctype="multipart/form-data">'
				. '<h3>' . $this->t('Envoyer un fichier') . '</h3>'
				. '<p>'
				. '<input type="file" name="file">'
				. '<div class="tip">' . $this->t('Taille maximale autorisée par le serveur :') . ' ' . ini_get('upload_max_filesize') . '</div>'
				. '</p>'
				. '<p>'
				. '<input type="submit" name="submit" value="' . $this->t('Envoyer') . '">'
				. '</p>'
				. '</form>'
				.  '<h3>' . $this->t('Mes fichiers') . '</h3>'
				. '<table>'
				. '<tr><th>' . $this->t('Nom') . '</th><th>' . $this->t('Taille') . '</th><th>' . $this->t('Actions') . '</th></tr>'
				. $this->files_list()
				. '</table>';
		}
	}

	function rename()
	{
		if(!isset($this->url[2])
		|| !file_exists($this->file_path . $this->url[2]))
		{
			return $this->error;
		}
		elseif(isset($_POST['submit']))
		{
			if(empty($_POST['name']))
			{
				$_SESSION['POPUP'] = $this->t('Impossible de renommer le fichier !');
			}
			else
			{
				$_SESSION['POPUP'] = $this->t('Fichier renommé avec succès !');
				$extension = pathinfo($this->url[2], PATHINFO_EXTENSION);
				$name = $_POST['name'] . '.' . $extension;
				if($name == $this->url[2])
				{
					$name = $_POST['name'];
				}
				else
				{
					$name = $this->increment($this->clean($_POST['name']), '.' . $extension, $this->file_path);
				}
				$file = $this->file_path . $name . '.' . $extension;
				rename($this->file_path . $this->url[2], $file);
			}
			return $this->redirect('/files_manager');
		}
		else
		{
			$name = pathinfo($this->url[2], PATHINFO_FILENAME);
			return '<h2>' . $this->title . '</h2>'
				. '<form name="form" method="post">'
				. '<p>'
				. '<label>' . $this->t('Nom') . '</label>'
				. '<input type="text" name="name" value="' . $name . '">'
				. '</p>'
				. '<p>'
				. '<input type="submit" name="submit" value="' . $this->t('Enregistrer') . '"> '
				. '<input type="button" value="' . $this->t('Retour') . '" onClick="history.back()">'
				. '</p>'
				. '</form>';
		}
	}

	function delete()
	{
		if(!isset($this->url[2])
		|| !file_exists($this->file_path . $this->url[2]))
		{
			return $this->error;
		}
		else
		{
			if(false !== unlink($this->file_path . $this->url[2]))
			{
				$_SESSION['POPUP'] = $this->t('Fichier supprimé avec succès !');
			}
			else
			{
				$_SESSION['POPUP'] = $this->t('Impossible de supprimer le fichier !');
			}
			return $this->redirect('/files_manager');
		}
	}

	/*
		Fonctions
	*/

	function upload()
	{
		if($_FILES['file']['size'] == 0)
		{
			return $_SESSION['POPUP'] = $this->t('Aucun fichier à télécharger !');
		}
		else
		{
			$name = pathinfo($_FILES['file']['name'], PATHINFO_FILENAME);
			$extension = pathinfo($_FILES['file']['name'], PATHINFO_EXTENSION);
			$new_name = $this->increment($this->clean($name), '.' . $extension, $this->file_path);
			$file = $this->file_path . $new_name . '.' . $extension;
			if(false !== move_uploaded_file($_FILES['file']['tmp_name'], $file))
			{
				return $_SESSION['POPUP'] = $this->t('Fichier téléchargé avec succès !');
			}
			else
			{
				return $_SESSION['POPUP'] = $this->t('Impossible de télécharger le fichier !');
			}
		}
	}

	function files_list()
	{
		$handle = opendir($this->file_path);
		while(false !== ($entry = readdir($handle)))
		{
			if(is_file($this->file_path . $entry))
			{
				$filesize = filesize($this->file_path . $entry) / 1024;
				$filesize = round($filesize);
				@$files .= '<tr>'
						. '<td>' . $entry . '</td>'
						. '<td>' . $filesize . ' ko</td>'
						. '<td>'
						. '<a href="' . $this->file_path . $entry . '" target="_blank"><img src="' . $this->icons_path . 'preview.png" title="' . $this->t('Afficher') . '" alt="' . $this->t('Afficher') . '"></a> '
						. '<a href="?/files_manager/rename/' . $entry . '"><img src="' . $this->icons_path . 'rename.png" title="' . $this->t('Renommer') . '" alt="' . $this->t('Renommer') . '"></a> '
						. '<a href="?/files_manager/delete/' . $entry . '" onClick=\'return confirm("' . $this->t('Êtes-vous certain de vouloir supprimer ce fichier ?') . '")\'><img src="' . $this->icons_path . 'delete.png" title="' . $this->t('Supprimer') . '" alt="' . $this->t('Supprimer') . '"></a> '
						. '</td>'
						. '</tr>';
			}
		}
		closedir($handle);
		return (isset($files)) ? $files : '<tr><td colspan="3">' . $this->t('Aucun fichier.') . '</td></tr>';
	}
}

?>